/**
 * PathCheckTool 类，用于精确匹配和前缀匹配路径，并支持更换前缀和创建子工具。
 */
export class PathCheckTool {
    url;
    prefix;
    pathname;
    constructor(url, prefix) {
        this.url = url;
        this.prefix = prefix;
        this.pathname = new URL(url).pathname;
    }
    makePath(path) {
        return `${this.prefix || ""}${path}`;
    }
    /**
     * 检查路径是否与基础 URL 的路径精确匹配。
     * @param {string} path - 要检查的路径。
     * @returns {boolean} 如果路径精确匹配则返回 true，否则返回 false。
     */
    exact(path) {
        return this.pathname === this.makePath(path);
    }
    /**
     * 检查路径是否以基础 URL 的路径为前缀。
     * @param {string} path - 要检查的路径。
     * @returns {boolean} 如果路径以基础 URL 的路径为前缀则返回 true，否则返回 false。
     */
    startsWith(path) {
        return this.pathname.startsWith(this.makePath(path));
    }
    /**
     * 检查完整路径是否与基础 URL 的路径精确匹配。
     * @param {string} path - 要检查的路径。
     * @returns {boolean} 如果完整路径与基础 URL 的路径精确匹配则返回 true，否则返回 false。
     */
    full(path) {
        return this.pathname === path;
    }
    /**
     * 创建一个子工具，继承当前工具的 URL 和前缀。
     * @param {string} [childPrefix] - 子工具的路径前缀。
     * @returns {PathCheckTool} 新的子工具实例。
     */
    child(childPrefix) {
        return new PathCheckTool(this.url, childPrefix || this.prefix);
    }
}
/**
 * 裁剪路径字符串，如果路径长度超过20个字符，则只保留最后两级目录。
 *
 * @param {string} path - 要处理的路径字符串。
 * @returns {string} - 裁剪后的路径字符串，如果长度不超过20个字符则返回原路径。
 */
export const shortenPath = (path) => {
    if (path.length <= 20) {
        return path;
    }
    const parts = path.split("/");
    if (parts.length <= 2) {
        return path;
    }
    return `.../${parts[parts.length - 2]}/${parts[parts.length - 1]}`;
};
//# sourceMappingURL=index.js.map